@@ -3,7 +3,7 @@ from __future__ import absolute_import, unicode_literals
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from logical.models import Database
-from physical.models import Instance
+from physical.models import DatabaseInfra
 import simple_audit
 
 ERROR = 0
@@ -49,18 +49,19 @@ class DatabaseBind(BaseModel):
         return "{} access to {}".format(self.bind_address, self.database)
 
 
-class InstanceBind(BaseModel):
+class DatabaseInfraInstanceBind(BaseModel):
 
-    instance =  models.ForeignKey(Instance, related_name="acl_binds", on_delete=models.PROTECT)
+    databaseinfra = models.ForeignKey(DatabaseInfra, related_name="acl_binds",)
+    instance =  models.GenericIPAddressField(verbose_name=_("Address"), null=False, blank=False, editable=False)
     bind_address = models.GenericIPAddressField(verbose_name=_("Address"), null=False, blank=False, editable=False)
     bind_status = models.IntegerField(choices=BIND_STATUS,default=2)
 
     class Meta:
         unique_together = (
-            ('instance', 'bind_address', )
+            ('instance', 'bind_address', 'databaseinfra')
         )
 
     def __unicode__(self):
         return "{} access to {}".format(self.bind_address, self.instance)
 
-simple_audit.register(InstanceBind, DatabaseBind)
+simple_audit.register(DatabaseInfraInstanceBind, DatabaseBind)
