@@ -1,7 +1,8 @@
 from ..acl_base_client import AclClient
 from util import get_credentials_for
 from dbaas_credentials.models import CredentialType
-from ..models import DatabaseBind, InstanceBind, CREATING
+from ..models import DatabaseBind, DatabaseInfraInstanceBind, CREATING
+from dbaas_cloudstack.models import DatabaseInfraAttr
 import logging
 from time import sleep
 
@@ -36,17 +37,22 @@ def bind_unbind_address_on_database(database, acl_environment, acl_vlan, action=
         bind.bind_status = bind_status
         bind.save()
 
-    instances = database.infra.instances.all()
+    databaseinfra = database.infra
+    instances = databaseinfra.instances.all()
+
+    port = instances[0].port
+
     for instance in instances:
         custom_options = default_options
         custom_options['source'] = bind_address
         custom_options['destination'] = instance.address + '/32'
-        custom_options['l4-options']['dest-port-start'] = instance.port
+        custom_options['l4-options']['dest-port-start'] = port
         data['rules'].append(custom_options)
 
         LOG.debug("Creating bind for instance: {}".format(instance))
 
-        bind_instance, created = InstanceBind.objects.get_or_create(instance= instance,
+        bind_instance, created = DatabaseInfraInstanceBind.objects.get_or_create(instance= instance.address,
+                                                                                                     databaseinfra= databaseinfra,
                                                                                                      bind_address= bind_address,
                                                                                                      defaults={'bind_status': CREATING}
                                                                                                     )
@@ -56,6 +62,25 @@ def bind_unbind_address_on_database(database, acl_environment, acl_vlan, action=
 
         LOG.debug("InstanceBind: {}, created? {}".format(bind_instance, created))
 
+    for instance in DatabaseInfraAttr.objects.filter(databaseinfra= databaseinfra):
+        custom_options = default_options
+        custom_options['source'] = bind_address
+        custom_options['destination'] = instance.ip + '/32'
+        custom_options['l4-options']['dest-port-start'] = port
+        data['rules'].append(custom_options)
+
+        LOG.debug("Creating bind for instance: {}".format(instance))
+
+        bind_instance, created = DatabaseInfraInstanceBind.objects.get_or_create(instance= instance.ip,
+                                                                                                     databaseinfra= databaseinfra,
+                                                                                                     bind_address= bind_address,
+                                                                                                     defaults={'bind_status': CREATING}
+                                                                                                    )
+        if not created:
+            bind_instance.bind_status = bind_status
+            bind_instance.save()
+
+
     acl_credential = get_credentials_for(environment= database.environment, credential_type=CredentialType.ACLAPI)
     acl_client = AclClient(acl_credential.endpoint, acl_credential.user, acl_credential.password)
 
