@@ -1,4 +1,4 @@
-from models import DatabaseBind, InstanceBind, CREATED, CREATING, ERROR
+from models import DatabaseBind, DatabaseInfraInstanceBind, CREATED, CREATING, ERROR
 import logging
 
 logging.basicConfig()
@@ -15,8 +15,8 @@ def update_bind_status(database, bind_address, bind_status):
         bind_status = CREATED
 
     bind = DatabaseBind.objects.get(database= database, bind_address= bind_address)
-    instances = database.infra.instances.all()
-    bind_instances = InstanceBind.objects.filter(instance__in= instances,  bind_address= bind_address)
+    databaseinfra = database.databaseinfra
+    bind_instances = DatabaseInfraInstanceBind.objects.filter(databaseinfra=databaseinfra,  bind_address= bind_address)
 
     if bind_status == 0:
         bind.delete()
